@@ -1,4 +1,4 @@
-#' Get species habitats by taxon name or IUCN id
+#' Get species habitats by taxon name, IUCN id, and region
 #'
 #' @export
 #' @template commonargs
@@ -26,12 +26,12 @@ rl_habitats_ <- function(name = NULL, id = NULL, region = NULL, key = NULL, ...)
 .habitats <- function(name = NULL, id = NULL, region = NULL) {
   stopifnot(xor(!is.null(name), !is.null(id)))
   path <- if (!is.null(name)) {
-    file.path("habitats/species/name", name)
+    file.path("habitats/species/name", space(name))
   } else {
     file.path("habitats/species/id", id)
   }
   if (!is.null(region)) {
-    path <- file.path(path, "region", region)
+    path <- file.path(path, "region", space(region))
   }
   path
 }
