@@ -1,4 +1,4 @@
-#' Get species narrative information by taxon name or IUCN id
+#' Get species synonym information by taxonomic name
 #'
 #' @export
 #' @param name (character) Binomial taxonomic name
@@ -16,5 +16,5 @@ rl_synonyms <- function(name = NULL, key = NULL, parse = TRUE, ...) {
 #' @export
 #' @rdname rl_synonyms
 rl_synonyms_ <- function(name = NULL, key = NULL, ...) {
-  rr_GET(file.path("species/synonym", name), key, ...)
+  rr_GET(file.path("species/synonym", space(name)), key, ...)
 }
